@@ -33,7 +33,7 @@
 #include <tqdir.h>
 #include <tqfileinfo.h>
 #include <tqregexp.h>
-#include <kconfig.h>
+#include <tdeconfig.h>
 #include <kdebug.h>
 
 #include <pilotSysInfo.h>
@@ -413,8 +413,8 @@ void SysInfoConduit::pcVersionInfo()
 				.arg(TQString::fromLatin1(name.machine));
 			fValues[CSL1("hostname")] = CSL1("%2").arg(TQString::fromLatin1(name.nodename));
 		}
-#ifdef KDE_VERSION_STRING
-		fValues[CSL1("kde")] = TQString::fromLatin1(KDE_VERSION_STRING);
+#ifdef TDE_VERSION_STRING
+		fValues[CSL1("kde")] = TQString::fromLatin1(TDE_VERSION_STRING);
 #endif
 #ifdef TQT_VERSION_STR
 		fValues[CSL1("qt")] = TQString::fromLatin1(TQT_VERSION_STR);
